@@ -10,6 +10,7 @@
 
 #include "generator.h"
 #include "generator_p.h"
+#include "observer.h"
 
 #include <qeventloop.h>
 #include <QtGui/QPrinter>
@@ -254,7 +255,6 @@ bool Generator::canGenerateTextPage() const
 
 void Generator::generateTextPage( Page *page )
 {
-    Q_D( Generator );
     TextPage *tp = textPage( page );
     page->setTextPage( tp );
     signalTextGenerationDone( page, tp );
@@ -478,6 +478,19 @@ void PixmapRequestPrivate::swap()
     qSwap( mWidth, mHeight );
 }
 
+bool PixmapRequestPrivate::isPreload() const
+{
+    switch ( mPriority )
+    {
+        case PAGEVIEW_PRELOAD_PRIO:
+        case THUMBNAILS_PRELOAD_PRIO:
+        case PRESENTATION_PRELOAD_PRIO:
+            return true;
+        default:
+            return false;
+    }
+}
+
 class Okular::ExportFormatPrivate : public QSharedData
 {
     public:
